ChannelEventSource

Struct ChannelEventSource 

pub struct ChannelEventSource<Event> { /* private fields */ }
A channel-based event source that receives events from a Tokio MPSC channel

Implementations

Source

impl<Event> ChannelEventSource<Event>
where Event: Send + 'static,

pub fn new(capacity: usize) -> (Self, Sender<Event>)

Create a new channel event source with a default ID

pub fn with_id(capacity: usize, id: impl Into<String>) -> (Self, Sender<Event>)

Create a new channel event source with a specific ID