NestedEventDrivenWorkflow

Struct NestedEventDrivenWorkflow 

pub struct NestedEventDrivenWorkflow<E, C, A>
where E: Send + 'static, C: Send + Sync + 'static, A: ActionType + Send + Sync + 'static + Default,
{ /* private fields */ }
A nested event-driven workflow that can be used in a standard workflow

Implementations

Source

impl<E, C, A> NestedEventDrivenWorkflow<E, C, A>
where E: Send + 'static, C: Send + Sync + 'static, A: ActionType + Send + Sync + 'static + Default,

pub fn new( workflow: Arc<EventDrivenWorkflow<E, C, A>>, complete_action: A, timeout_action: A, ) -> Self

Create a new nested workflow without a timeout

pub fn with_timeout( workflow: Arc<EventDrivenWorkflow<E, C, A>>, timeout: Duration, complete_action: A, timeout_action: A, ) -> Self

Create a new nested workflow with a timeout

pub fn with_id( workflow: Arc<EventDrivenWorkflow<E, C, A>>, id: impl Into<String>, complete_action: A, timeout_action: A, ) -> Self

Create a new nested workflow with a specific ID